# Lazy Op(eration)s or lazyops
  
  **Latest Version**: [![PyPI version](https://badge.fury.io/py/lazyops.svg)](https://badge.fury.io/py/lazyops)

  A collection of submodules/patterns that are commonly used within personal projects. 

**Deprecation Notice**

  If you are looking for the previous version of `lazyops`, please see the `v0.2.x` tag. This is the last stable version of the previous implementation of `lazyops` prior to rework of the entire project.

  New APIs are implemented in `v0.2.x` and above.

---

### Installation
Install directory from pypi

`pip install --upgrade lazyops`

Install from Github

`pip install --upgrade git+https://github.com/trisongz/lazyops`

---

### Usage

Work in Progress

```python
```


---

### Dependencies

- Python 3.7+
- [pydantic](https://github.com/pydantic/pydantic)

- [loguru](https://github.com/Delgan/loguru)
